# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [0.1.5] - 2025-05-17

### Changed

- 优化tests/base.py示例

### Added

- 增加astro.by_lunar(...) 农历排盘
- 增加config(...)设置配置方法
- 增加getConfig(...)获取配置方法
- 增加tests/config.py示例
